@@ -91,8 +91,8 @@ start on the same column in the file. The value of the pair should be
 indented to the right of the key.
 
 The lexical syntax for section names is identical to the lexical syntax
-of /atoms/. Section names are nonempty sequences starting with an /alpha/
-character followed by zero or more /alpha/, /digit/, /period/ (.),
+of /atoms/. Section names are nonempty sequences starting with an /alpha/,
+@$@ or @\@@ character followed by zero or more /alpha/, /digit/, /period/ (.),
 underscore (_), or dash (-).
 
 Section lists can be nested.
@@ -128,9 +128,11 @@ list element may be terminated with a trailing comma.
 
 Example: @[1, 2, 3]@
 
-Layout list entries are started with a leading @*@. Each leading @*@ must occur
-in the some column of the file. Lists can be nested by starting the new list
-on a column to the right of the current list.
+Layout list entries are started with a leading @*@, @+@, or @-@. Each leading bullet
+must occur in the some column of the file. Lists can be nested by starting the new
+list on a column to the right of the current list. A single list must use the same
+bullet token for every element of the list. Nested lists can choose a different
+bullet. This can help visually distinguish nested lists.
 
 Layout based lists can not occur inside inline list syntax. Layout based section lists
 can occur inside layout based lists
@@ -205,8 +207,9 @@ unquoted-string
 /Atoms/ are unquoted strings that are distinct from normal /text/ values.
 This type is intended to represent enumerations in a configuration file.
 
-Atoms are nonempty sequences starting with an /alpha/ character followed by
-zero or more /alpha/, /digit/, /period/ (.), underscore (_), or dash (-).
+Atoms are nonempty sequences starting with an /alpha/, @$@, or @\@@ character
+followed by zero or more /alpha/, /digit/, /period/ (.), underscore (_), or
+dash (-).
 
 Lexical syntax: @$alpha [$alpha $digit $unidigit \\. _ \\-]*@
 
@@ -270,8 +273,6 @@ import           Config.Tokens (Error(..), Position(..), Located(..), layoutPass
 import qualified Config.Tokens as T
 
 import           Control.Exception (Exception(..))
-import           Numeric (showIntAtBase)
-import           Data.Char (intToDigit)
 import           Data.Text (Text)
 import qualified Data.Text as Text
 
@@ -306,7 +307,7 @@ explainToken token =
     T.Error e     -> explainError e
     T.Atom atom   -> "parse error: unexpected atom: `" ++ Text.unpack atom ++ "`"
     T.String str  -> "parse error: unexpected string: " ++ show (Text.unpack str)
-    T.Bullet      -> "parse error: unexpected bullet '*'"
+    T.Bullet s    -> "parse error: unexpected bullet '" ++ Text.unpack s ++ "'"
     T.Comma       -> "parse error: unexpected comma ','"
     T.Section s   -> "parse error: unexpected section: `" ++ Text.unpack s ++ "`"
     T.Number{}    -> "parse error: unexpected number"
@@ -318,11 +319,6 @@ explainToken token =
     T.LayoutEnd   -> "parse error: unexpected end of block"
     T.EOF         -> "parse error: unexpected end of file"
 
-showIntAtBase' :: (Show a, Integral a) => String -> a -> (Int -> Char) -> a -> ShowS
-showIntAtBase' pfx base toDigit n
-  | n < 0     = showChar '-' . showString pfx . showIntAtBase base toDigit (negate n)
-  | otherwise =                showString pfx . showIntAtBase base toDigit n
-
 explainError :: Error -> String
 explainError e =
   case e of
